package cache
import "github.com/containerd/nydus-snapshotter/pkg/cache"
Index ¶
- func ExtractBlobIDFromFilename(filename string) string
- type Manager
- func NewManager(opt Opt) (*Manager, error)
- func (m *Manager) CacheDir() string
- func (m *Manager) CacheUsage(ctx context.Context, blobID string) (snapshots.Usage, error)
- func (m *Manager) RemoveBlobCache(blobID string) error
- type Opt
Functions ¶
func ExtractBlobIDFromFilename ¶
extractBlobIDFromFilename extracts the blob ID from a cache filename Cache files can have formats like: - <blobID> - <blobID>.blob.data - <blobID>.chunk_map - <blobID>.blob.meta - <blobID>.image.disk - <blobID>.layer.disk
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Disk cache manager for fusedev.
func NewManager ¶
func (*Manager) CacheDir ¶
func (*Manager) CacheUsage ¶
Report each blob disk usage TODO: For fscache cache files, the cache files are managed by nydusd and Linux kernel We don't know how it manages cache files. A method to address this is to query nydusd. So we can't report cache usage in the case of fscache now
func (*Manager) RemoveBlobCache ¶
type Opt ¶
Source Files ¶
- Version
- v0.15.15 (latest)
- Published
- Apr 17, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 1 hour ago –
Tools for package owners.