index

package
v0.15.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNoNydusAlternative = errors.New("no alternative nydus descriptor found in index")

Functions

This section is empty.

Types

type Manager

type Manager struct {
	// contains filtered or unexported fields
}

func NewManager

func NewManager(insecure bool) *Manager

func (*Manager) CheckIndexAlternative

func (manager *Manager) CheckIndexAlternative(ctx context.Context, ref string, manifestDigest digest.Digest) (*ocispec.Descriptor, error)

CheckIndexAlternative attempts to find a nydus alternative manifest within an OCI index manifest for the specified manifest digest.

func (*Manager) TryFetchMetadata

func (manager *Manager) TryFetchMetadata(ctx context.Context, ref string, manifestDigest digest.Digest, metadataPath string) error

TryFetchMetadata try to fetch and unpack nydus metadata file to specified path.

Jump to